@@ -13,6 +13,7 @@ pub enum Error {
         ip_str: String,
         err: std::net::AddrParseError,
     },
+    InvalidComponentRange(time::error::ComponentRange),
 }
 
 impl std::error::Error for Error {
@@ -25,6 +26,7 @@ impl std::error::Error for Error {
             Self::Transport(transport) => transport,
             Self::ParseInteger(parse) => parse,
             Self::InvalidIp { err, .. } => err,
+            Self::InvalidComponentRange(_err) => return None,
         })
     }
 }
@@ -46,6 +48,9 @@ impl fmt::Display for Error {
             Self::InvalidIp { ip_str, err } => {
                 write!(f, "failed to parse ip '{}': {}", ip_str, err)
             }
+            Self::InvalidComponentRange(cr) => {
+                write!(f, "invalid component range: {}", cr)
+            }
         }
     }
 }
@@ -77,3 +82,10 @@ impl From<tonic::transport::Error> for Error {
         Self::Transport(e)
     }
 }
+
+impl From<time::error::ComponentRange> for Error {
+    #[inline]
+    fn from(e: time::error::ComponentRange) -> Self {
+        Self::InvalidComponentRange(e)
+    }
+}
